@@ -29,10 +29,6 @@ const SUPPORTED_WASM_FEATURES: &[(&str, &str)] = &[
         "bulk-memory",
         "enables support for bulk memory instructions",
     ),
-    (
-        "module-linking",
-        "enables support for the module-linking proposal",
-    ),
     (
         "multi-memory",
         "enables support for the multi-memory proposal",
@@ -234,7 +230,14 @@ struct CommonOptions {
     #[structopt(long)]
     enable_cranelift_nan_canonicalization: bool,
 
-    #[structopt(long)]
+    /// Enable execution fuel with N units fuel, where execution will trap after
+    /// running out of fuel.
+    ///
+    /// Most WebAssembly instructions consume 1 unit of fuel. Some instructions,
+    /// such as `nop`, `drop`, `block`, and `loop`, consume 0 units, as any
+    /// execution cost associated with them involves other instructions which do
+    /// consume fuel.
+    #[structopt(long, value_name = "N")]
     fuel: Option<u64>,
 
     /// Executing wasm code will yield when a global epoch counter
@@ -367,7 +370,6 @@ impl CommonOptions {
             threads,
             multi_memory,
             memory64,
-            module_linking,
         } = self.wasm_features.unwrap_or_default();
 
         if let Some(enable) = simd {
@@ -377,7 +379,9 @@ impl CommonOptions {
             config.wasm_bulk_memory(enable);
         }
         if let Some(enable) = reference_types {
+            #[cfg(feature = "wasm-backtrace")]
             config.wasm_reference_types(enable);
+            drop(enable); // suppress unused warnings
         }
         if let Some(enable) = multi_value {
             config.wasm_multi_value(enable);
@@ -391,9 +395,6 @@ impl CommonOptions {
         if let Some(enable) = memory64 {
             config.wasm_memory64(enable);
         }
-        if let Some(enable) = module_linking {
-            config.wasm_module_linking(enable);
-        }
     }
 
     fn opt_level(&self) -> wasmtime::OptLevel {
@@ -423,7 +424,6 @@ struct WasmFeatures {
     multi_value: Option<bool>,
     bulk_memory: Option<bool>,
     simd: Option<bool>,
-    module_linking: Option<bool>,
     threads: Option<bool>,
     multi_memory: Option<bool>,
     memory64: Option<bool>,
@@ -471,7 +471,6 @@ fn parse_wasm_features(features: &str) -> Result<WasmFeatures> {
         reference_types: all.or(values["reference-types"]),
         multi_value: all.or(values["multi-value"]),
         bulk_memory: all.or(values["bulk-memory"]),
-        module_linking: all.or(values["module-linking"]),
         simd: all.or(values["simd"]),
         threads: all.or(values["threads"]),
         multi_memory: all.or(values["multi-memory"]),
@@ -574,7 +573,6 @@ mod test {
             reference_types,
             multi_value,
             bulk_memory,
-            module_linking,
             simd,
             threads,
             multi_memory,
@@ -584,7 +582,6 @@ mod test {
         assert_eq!(reference_types, Some(true));
         assert_eq!(multi_value, Some(true));
         assert_eq!(bulk_memory, Some(true));
-        assert_eq!(module_linking, Some(true));
         assert_eq!(simd, Some(true));
         assert_eq!(threads, Some(true));
         assert_eq!(multi_memory, Some(true));
@@ -601,7 +598,6 @@ mod test {
             reference_types,
             multi_value,
             bulk_memory,
-            module_linking,
             simd,
             threads,
             multi_memory,
@@ -611,7 +607,6 @@ mod test {
         assert_eq!(reference_types, Some(false));
         assert_eq!(multi_value, Some(false));
         assert_eq!(bulk_memory, Some(false));
-        assert_eq!(module_linking, Some(false));
         assert_eq!(simd, Some(false));
         assert_eq!(threads, Some(false));
         assert_eq!(multi_memory, Some(false));
@@ -631,7 +626,6 @@ mod test {
             reference_types,
             multi_value,
             bulk_memory,
-            module_linking,
             simd,
             threads,
             multi_memory,
@@ -641,7 +635,6 @@ mod test {
         assert_eq!(reference_types, Some(false));
         assert_eq!(multi_value, None);
         assert_eq!(bulk_memory, None);
-        assert_eq!(module_linking, None);
         assert_eq!(simd, Some(true));
         assert_eq!(threads, None);
         assert_eq!(multi_memory, Some(true));
@@ -682,11 +675,6 @@ mod test {
     );
     feature_test!(test_multi_value_feature, multi_value, "multi-value");
     feature_test!(test_bulk_memory_feature, bulk_memory, "bulk-memory");
-    feature_test!(
-        test_module_linking_feature,
-        module_linking,
-        "module-linking"
-    );
     feature_test!(test_simd_feature, simd, "simd");
     feature_test!(test_threads_feature, threads, "threads");
     feature_test!(test_multi_memory_feature, multi_memory, "multi-memory");
