@@ -1,9 +1,11 @@
-use std::sync::atomic::{AtomicUsize, Ordering::SeqCst};
+use std::sync::atomic::{AtomicBool, AtomicUsize, Ordering::SeqCst};
 use wasmtime::*;
 
 fn interruptable_store() -> Store<()> {
-    let engine = Engine::new(Config::new().interruptable(true)).unwrap();
-    Store::new(&engine, ())
+    let engine = Engine::new(Config::new().epoch_interruption(true)).unwrap();
+    let mut store = Store::new(&engine, ());
+    store.set_epoch_deadline(1);
+    store
 }
 
 fn hugely_recursive_module(engine: &Engine) -> anyhow::Result<Module> {
@@ -28,9 +30,13 @@ fn loops_interruptable() -> anyhow::Result<()> {
     let module = Module::new(store.engine(), r#"(func (export "loop") (loop br 0))"#)?;
     let instance = Instance::new(&mut store, &module, &[])?;
     let iloop = instance.get_typed_func::<(), (), _>(&mut store, "loop")?;
-    store.interrupt_handle()?.interrupt();
+    store.engine().increment_epoch();
     let trap = iloop.call(&mut store, ()).unwrap_err();
-    assert!(trap.to_string().contains("wasm trap: interrupt"));
+    assert!(
+        trap.to_string().contains("epoch deadline reached"),
+        "bad message: {}",
+        trap
+    );
     Ok(())
 }
 
@@ -41,22 +47,25 @@ fn functions_interruptable() -> anyhow::Result<()> {
     let func = Func::wrap(&mut store, || {});
     let instance = Instance::new(&mut store, &module, &[func.into()])?;
     let iloop = instance.get_typed_func::<(), (), _>(&mut store, "loop")?;
-    store.interrupt_handle()?.interrupt();
+    store.engine().increment_epoch();
     let trap = iloop.call(&mut store, ()).unwrap_err();
     assert!(
-        trap.to_string().contains("wasm trap: interrupt"),
+        trap.to_string().contains("epoch deadline reached"),
         "{}",
         trap.to_string()
     );
     Ok(())
 }
 
+const NUM_HITS: usize = 100_000;
+
 #[test]
 fn loop_interrupt_from_afar() -> anyhow::Result<()> {
     // Create an instance which calls an imported function on each iteration of
     // the loop so we can count the number of loop iterations we've executed so
     // far.
     static HITS: AtomicUsize = AtomicUsize::new(0);
+    static STOP: AtomicBool = AtomicBool::new(false);
     let mut store = interruptable_store();
     let module = Module::new(
         store.engine(),
@@ -75,24 +84,26 @@ fn loop_interrupt_from_afar() -> anyhow::Result<()> {
     });
     let instance = Instance::new(&mut store, &module, &[func.into()])?;
 
-    // Use the instance's interrupt handle to wait for it to enter the loop long
-    // enough and then we signal an interrupt happens.
-    let handle = store.interrupt_handle()?;
+    // Use the engine to wait for it to enter the loop long enough and then we
+    // signal an interrupt happens.
+    let engine = store.engine().clone();
     let thread = std::thread::spawn(move || {
-        while HITS.load(SeqCst) <= 100_000 {
+        while HITS.load(SeqCst) <= NUM_HITS && !STOP.load(SeqCst) {
             // continue ...
         }
         println!("interrupting");
-        handle.interrupt();
+        engine.increment_epoch();
     });
 
     // Enter the infinitely looping function and assert that our interrupt
     // handle does indeed actually interrupt the function.
     let iloop = instance.get_typed_func::<(), (), _>(&mut store, "loop")?;
     let trap = iloop.call(&mut store, ()).unwrap_err();
+    STOP.store(true, SeqCst);
     thread.join().unwrap();
+    assert!(HITS.load(SeqCst) > NUM_HITS);
     assert!(
-        trap.to_string().contains("wasm trap: interrupt"),
+        trap.to_string().contains("epoch deadline reached"),
         "bad message: {}",
         trap.to_string()
     );
@@ -105,6 +116,8 @@ fn function_interrupt_from_afar() -> anyhow::Result<()> {
     // the loop so we can count the number of loop iterations we've executed so
     // far.
     static HITS: AtomicUsize = AtomicUsize::new(0);
+    static STOP: AtomicBool = AtomicBool::new(false);
+
     let mut store = interruptable_store();
     let module = hugely_recursive_module(store.engine())?;
     let func = Func::wrap(&mut store, || {
@@ -114,21 +127,23 @@ fn function_interrupt_from_afar() -> anyhow::Result<()> {
 
     // Use the instance's interrupt handle to wait for it to enter the loop long
     // enough and then we signal an interrupt happens.
-    let handle = store.interrupt_handle()?;
+    let engine = store.engine().clone();
     let thread = std::thread::spawn(move || {
-        while HITS.load(SeqCst) <= 100_000 {
+        while HITS.load(SeqCst) <= NUM_HITS && !STOP.load(SeqCst) {
             // continue ...
         }
-        handle.interrupt();
+        engine.increment_epoch();
     });
 
     // Enter the infinitely looping function and assert that our interrupt
     // handle does indeed actually interrupt the function.
     let iloop = instance.get_typed_func::<(), (), _>(&mut store, "loop")?;
     let trap = iloop.call(&mut store, ()).unwrap_err();
+    STOP.store(true, SeqCst);
     thread.join().unwrap();
+    assert!(HITS.load(SeqCst) > NUM_HITS);
     assert!(
-        trap.to_string().contains("wasm trap: interrupt"),
+        trap.to_string().contains("epoch deadline reached"),
         "bad message: {}",
         trap.to_string()
     );
